package com.ruoyi.llm.mapper;

import java.util.List;
import com.ruoyi.llm.domain.CmcDocument;

/**
 * cmc聊天附件Mapper接口
 * 
 * @author cmc
 * @date 2025-04-08
 */
public interface CmcDocumentMapper 
{
    /**
     * 查询cmc聊天附件
     * 
     * @param documentId cmc聊天附件主键
     * @return cmc聊天附件
     */
    public CmcDocument selectCmcDocumentByDocumentId(String documentId);

    /**
     * 查询cmc聊天附件列表
     * 
     * @param cmcDocument cmc聊天附件
     * @return cmc聊天附件集合
     */
    public List<CmcDocument> selectCmcDocumentList(CmcDocument cmcDocument);

    /**
     * 新增cmc聊天附件
     * 
     * @param cmcDocument cmc聊天附件
     * @return 结果
     */
    public int insertCmcDocument(CmcDocument cmcDocument);

    /**
     * 修改cmc聊天附件
     * 
     * @param cmcDocument cmc聊天附件
     * @return 结果
     */
    public int updateCmcDocument(CmcDocument cmcDocument);

    /**
     * 删除cmc聊天附件
     * 
     * @param documentId cmc聊天附件主键
     * @return 结果
     */
    public int deleteCmcDocumentByDocumentId(String documentId);

    /**
     * 批量删除cmc聊天附件
     * 
     * @param documentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcDocumentByDocumentIds(String[] documentIds);
}
